@@ -16,12 +16,6 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-#' Fixed design using RMST method
-#'
-#' Computes fixed design sample size (given power) or power (given sample size)
-#' for RMST methods (Yung and Liu, 2020).
-#' Returns a list with a basic summary.
-#'
 #' @inheritParams gs_design_ahr
 #' @param alpha One-sided Type I error (strictly between 0 and 1).
 #' @param power Power (`NULL` to compute power or strictly between 0
@@ -30,11 +24,12 @@
 #' @param study_duration Study duration.
 #' @param tau Test parameter in RMST.
 #'
-#' @return A table.
-#'
 #' @export
 #'
+#' @rdname fixed_design
+#'
 #' @examples
+#' # RMST method ----
 #' library(dplyr)
 #'
 #' # Example 1: given power and compute sample size
@@ -110,7 +105,7 @@ fixed_design_rmst <- function(
     )
   }
   # get the output
-  ans <- tibble::tibble(
+  ans <- tibble(
     design = "rmst",
     n = d$analysis$n,
     event = d$analysis$event,
