@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
+#  Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
 #  All rights reserved.
 #
 #  This file is part of the gsDesign2 program.
@@ -62,20 +62,14 @@
 #' @details
 #' To be added.
 #'
-#' @importFrom gsDesign gsDesign sfLDOF
-#' @importFrom stats qnorm
-#' @importFrom dplyr mutate select arrange desc
-#'
 #' @export
 #'
 #' @examples
 #' library(gsDesign)
 #'
-#' # ----------------- #
-#' #    example 1      #
-#' #------------------ #
+#' # Example 1 ----
 #' # unstratified group sequential design
-#' gs_design_rd(
+#' x <- gs_design_rd(
 #'   p_c = tibble::tibble(stratum = "All", rate = .2),
 #'   p_e = tibble::tibble(stratum = "All", rate = .15),
 #'   info_frac = c(0.7, 1),
@@ -91,9 +85,24 @@
 #'   lpar = c(qnorm(.1), rep(-Inf, 2))
 #' )
 #'
-#' # ----------------- #
-#' #     example 2     #
-#' # ----------------- #
+#' y <- gs_power_rd(
+#'   p_c = tibble::tibble(stratum = "All", rate = .2),
+#'   p_e = tibble::tibble(stratum = "All", rate = .15),
+#'   n = tibble::tibble(stratum = "All", n = x$analysis$n, analysis = 1:2),
+#'   rd0 = 0,
+#'   ratio = 1,
+#'   weight = "unstratified",
+#'   upper = gs_b,
+#'   lower = gs_b,
+#'   upar = gsDesign(k = 2, test.type = 1, sfu = sfLDOF, sfupar = NULL)$upper$bound,
+#'   lpar = c(qnorm(.1), rep(-Inf, 2))
+#' )
+#'
+#' # The above 2 design share the same power with the same sample size and treatment effect
+#' x$bound$probability[x$bound$bound == "upper" & x$bound$analysis == 2]
+#' y$bound$probability[y$bound$bound == "upper" & y$bound$analysis == 2]
+#'
+#' # Example 2 ----
 #' # stratified group sequential design
 #' gs_design_rd(
 #'   p_c = tibble::tibble(
@@ -138,9 +147,7 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
                          r = 18,
                          tol = 1e-6,
                          h1_spending = TRUE) {
-  # --------------------------------------------- #
-  #     check input values                        #
-  # --------------------------------------------- #
+  # Check input values ----
   info_scale <- match.arg(info_scale)
 
   weight <- if (methods::missingArg(weight)) {
@@ -155,14 +162,11 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
     k <- length(info_frac)
   }
 
-  # --------------------------------------------- #
-  #     calculate the sample size                 #
-  #          under fixed design                   #
-  # --------------------------------------------- #
+  # Calculate the sample size under fixed design ----
   x_fix <- gs_info_rd(
     p_c = p_c,
     p_e = p_e,
-    n = tibble::tibble(
+    n = tibble(
       analysis = 1,
       stratum = p_c$stratum,
       n = if (is.null(stratum_prev)) {
@@ -176,14 +180,11 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
     weight = weight
   )
 
-  # --------------------------------------------- #
-  #     calculate the sample size                 #
-  #     under group sequential design             #
-  # --------------------------------------------- #
+  # Calculate the sample size under group sequential design ----
   x_gs <- gs_info_rd(
     p_c = p_c,
     p_e = p_e,
-    n = tibble::tibble(
+    n = tibble(
       analysis = rep(1:k, n_strata),
       stratum = rep(p_c$stratum, each = k),
       n = if (is.null(stratum_prev)) {
@@ -204,8 +205,8 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
   }
 
   if (h1_spending) {
-    theta1 <- x$theta
-    info1 <- x$info
+    theta1 <- x$theta1
+    info1 <- x$info1
   } else {
     theta1 <- 0
     info1 <- x$info0
@@ -221,18 +222,13 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
     r = r, tol = tol
   )
 
-
-
-
-  # --------------------------------------------- #
-  #     get statistical information               #
-  # --------------------------------------------- #
+  # Get statistical information ----
   inflac_fct <- if (info_scale == "h0_info") {
     (y_gs %>% filter(bound == "upper", analysis == k))$info0 / x_fix$info0[1]
   } else if (info_scale == "h1_info") {
     (y_gs %>% filter(bound == "upper", analysis == k))$info1 / x_fix$info1[1]
   } else if (info_scale == "h0_h1_info") {
-    (y_gs %>% filter(bound == "upper", analysis == k))$info1 / x_fix$info0[1]
+    (y_gs %>% filter(bound == "upper", analysis == k))$info / x_fix$info1[1]
   }
 
   allout <- y_gs %>%
@@ -254,9 +250,7 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
     )) %>%
     arrange(analysis, desc(bound))
 
-  # --------------------------------------------- #
-  #     get input parameters to output            #
-  # --------------------------------------------- #
+  # Get input parameters to output ----
   input <- list(
     p_c = p_c, p_e = p_e,
     info_frac = info_frac, rd0 = rd0, alpha = alpha, beta = beta,
@@ -267,32 +261,22 @@ gs_design_rd <- function(p_c = tibble::tibble(stratum = "All", rate = .2),
     binding = binding, info_scale = info_scale, r = r, tol = tol
   )
 
-  # --------------------------------------------- #
-  #     get bounds to output                      #
-  # --------------------------------------------- #
+  # Get bounds to output ----
   bound <- allout %>%
     select(analysis, bound, probability, probability0, z, `~risk difference at bound`, `nominal p`)
 
-  # --------------------------------------------- #
-  #     get analysis summary to output            #
-  # --------------------------------------------- #
+  # Get analysis summary to output ----
   analysis <- allout %>%
     filter(bound == "upper") %>%
     select(analysis, n, rd, rd0, info, info0, info_frac, info_frac0)
 
-  # --------------------------------------------- #
-  #     return the output                         #
-  # --------------------------------------------- #
+  # Return the output ----
   ans <- list(
     input = input,
     bound = bound %>% filter(!is.infinite(z)),
     analysis = analysis
   )
 
-  class(ans) <- c("rd", "gs_design", class(ans))
-  if (!binding) {
-    class(ans) <- c("non_binding", class(ans))
-  }
-
+  ans <- add_class(ans, if (!binding) "non_binding", "rd", "gs_design")
   return(ans)
 }
