@@ -117,8 +117,6 @@
 #' }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
-#' @importFrom stats qnorm pnorm
-#'
 #' @export
 #'
 #' @examples
@@ -359,7 +357,7 @@ gs_power_npe <- function(theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
     }
   }
 
-  ans <- tibble::tibble(
+  ans <- tibble(
     analysis = rep(1:n_analysis, 2),
     bound = c(rep("upper", n_analysis), rep("lower", n_analysis)),
     z = c(b, a),
