@@ -41,14 +41,12 @@
 #' }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
-#' @importFrom mvtnorm GenzBretz
-#'
 #' @noRd
 gs_utility_combo <- function(enroll_rate,
                              fail_rate,
                              fh_test,
                              ratio = 1,
-                             algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
+                             algorithm = mvtnorm::GenzBretz(maxpts = 1e5, abseps = 1e-5),
                              ...) {
   # Define analysis time
   analysis_time <- sort(unique(fh_test$analysis_time))
@@ -112,7 +110,7 @@ gs_utility_combo <- function(enroll_rate,
   n <- max(info$n)
 
   # Restricted to actual analysis
-  info_fh <- info %>% left_join(fh_test %>% dplyr::rename(time = analysis_time), by = c("test", "analysis", "time"))
+  info_fh <- info %>% left_join(fh_test %>% rename(time = analysis_time), by = c("test", "analysis", "time"))
   corr_fh <- corr_combo[!is.na(info_fh$gamma), !is.na(info_fh$gamma)]
   info_fh <- subset(info_fh, !is.na(gamma))
 
@@ -140,15 +138,13 @@ gs_utility_combo <- function(enroll_rate,
 #' @param group The vector of test statistics group.
 #' @param ... Additional parameters passed to [mvtnorm::pmvnorm].
 #'
-#' @importFrom mvtnorm GenzBretz
-#'
 #' @noRd
 pmvnorm_combo <- function(lower,
                           upper,
                           group,
                           mean,
                           corr,
-                          algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
+                          algorithm = mvtnorm::GenzBretz(maxpts = 1e5, abseps = 1e-5),
                           ...) {
   # Number of test in each group
   n_test <- as.numeric(table(group))
@@ -328,15 +324,13 @@ gs_sigma2_combo <- function(arm0,
 #' @param theta A numeric vector of effect size under alternative hypothesis.
 #' @param corr A matrix of correlation matrix.
 #'
-#' @importFrom mvtnorm GenzBretz
-#'
 #' @noRd
 gs_prob_combo <- function(upper_bound,
                           lower_bound,
                           analysis,
                           theta,
                           corr,
-                          algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
+                          algorithm = mvtnorm::GenzBretz(maxpts = 1e5, abseps = 1e-5),
                           ...) {
   n_analysis <- length(unique(analysis))
 
@@ -415,8 +409,6 @@ gs_prob_combo <- function(upper_bound,
 #' }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
-#' @importFrom mvtnorm GenzBretz
-#'
 #' @examples
 #' library(gsDesign)
 #'
@@ -450,7 +442,7 @@ gs_bound <- function(alpha,
                      analysis = seq_along(alpha),
                      theta0 = rep(0, length(analysis)),
                      binding_lower_bound = FALSE,
-                     algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
+                     algorithm = mvtnorm::GenzBretz(maxpts = 1e5, abseps = 1e-5),
                      alpha_bound = FALSE,
                      beta_bound = FALSE,
                      ...) {
